==> vue-upload-2.8.0.tgz: package/lib/pc.js <==
import { defineComponent, $prefix, props, setup as _setup, h } from "@dft-vue-2-opentiny/vue-common";
import { renderless, api } from "@dft-vue-2-opentiny/vue-renderless/upload/vue";
import UploadDragger from "@dft-vue-2-opentiny/vue-upload-dragger";
import Modal from "@dft-vue-2-opentiny/vue-modal";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  inheritAttrs: false,
  name: $prefix + "Upload",
  props: [].concat(props, ["accept", "action", "autoUpload", "beforeUpload", "pasteUpload", "data", "disabled", "drag", "edmToken", "fileList", "headers", "httpRequest", "isFolder", "limit", "listType", "multiple", "name", "onError", "onExceed", "onPreview", "onProgress", "onRemove", "onStart", "onSuccess", "type", "withCredentials", "isHidden", "handleTriggerClick"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api,
      h,
      extendOptions: {
        Modal
      }
    });
  },
  render: function render() {
    var h2 = arguments[0];
    var accept = this.accept, disabled = this.disabled, drag = this.drag, handleChange = this.handleChange, handleClick = this.handleClick, handlePaste = this.handlePaste, handleKeydown = this.handleKeydown, isFolder = this.isFolder, listType = this.listType, multiple = this.multiple, name = this.name, uploadFiles = this.uploadFiles, fileList = this.fileList, limit = this.limit, isHidden = this.isHidden, type = this.type;
    var defaultSlot = this.slots.default && this.slots.default() || [];
    var hidden = isHidden && fileList.length >= limit;
    return h2("div", {
      "class": ["tiny-upload", "tiny-upload--" + listType, disabled ? "is-disabled" : "", hidden ? "is-hidden" : ""],
      "on": {
        "click": function click($event) {
          return handleClick($event, type);
        },
        "paste": handlePaste,
        "keydown": handleKeydown
      },
      "attrs": {
        "tabindex": "0"
      }
    }, [drag ? h2(UploadDragger, {
      "attrs": {
        "disabled": disabled
      },
      "on": {
        "file": uploadFiles
      }
    }, [defaultSlot]) : defaultSlot, h2("input", {
      "class": "tiny-upload__input",
      "attrs": {
        "type": "file",
        "webkitdirectory": isFolder,
        "name": name,
        "multiple": isFolder ? true : multiple,
        "accept": accept
      },
      "ref": "input",
      "on": {
        "change": handleChange
      }
    })]);
  }
});
var __vue2_render, __vue2_staticRenderFns;
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, __vue2_render, __vue2_staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-upload-2.21.0.tgz: package/lib/pc.js <==
import { defineComponent, $prefix, props, setup, h } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/upload/vue';
import UploadDragger from '@opentinyvue/vue-upload-dragger';
import Modal from '@opentinyvue/vue-modal';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  inheritAttrs: false,
  name: $prefix + "Upload",
  props: [].concat(props, ["accept", "action", "autoUpload", "beforeUpload", "pasteUpload", "data", "disabled", "drag", "edmToken", "fileList", "headers", "httpRequest", "isFolder", "limit", "listType", "multiple", "name", "onError", "onExceed", "onPreview", "onProgress", "onRemove", "onStart", "onSuccess", "type", "withCredentials", "isHidden", "handleTriggerClick"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      h,
      extendOptions: {
        Modal
      }
    });
  },
  render: function render() {
    var h2 = arguments[0];
    var accept = this.accept, disabled = this.disabled, drag = this.drag, handleChange = this.handleChange, handleClick = this.handleClick, handlePaste = this.handlePaste, handleKeydown = this.handleKeydown, isFolder = this.isFolder, listType = this.listType, multiple = this.multiple, name = this.name, uploadFiles = this.uploadFiles, fileList = this.fileList, limit = this.limit, isHidden = this.isHidden, type = this.type;
    var defaultSlot = this.slots.default && this.slots.default() || [];
    var operateSlot = this.slots.operate && this.slots.operate();
    var tipSlot = this.slots.tip && this.slots.tip();
    var hidden = isHidden && fileList.length >= limit;
    return !hidden && h2("div", {
      "class": ["tiny-upload", "tiny-upload--" + listType, disabled ? "is-disabled" : ""]
    }, [h2("div", {
      "class": "tiny-upload-btn",
      "on": {
        "click": function click($event) {
          return handleClick($event, type);
        },
        "paste": handlePaste,
        "keydown": handleKeydown
      },
      "attrs": {
        "tabindex": "0"
      }
    }, [drag ? h2(UploadDragger, {
      "attrs": {
        "disabled": disabled
      },
      "on": {
        "file": uploadFiles
      }
    }, [defaultSlot]) : defaultSlot]), operateSlot, tipSlot, h2("input", {
      "class": "tiny-upload__input",
      "attrs": {
        "type": "file",
        "webkitdirectory": isFolder,
        "name": name,
        "multiple": isFolder ? true : multiple,
        "accept": accept
      },
      "ref": "input",
      "on": {
        "change": handleChange
      }
    })]);
  }
});
var __vue2_render, __vue2_staticRenderFns;
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, __vue2_render, __vue2_staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
